﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Excercise01
{
    /// <summary>
    /// Intro to C# drawing + animation
    /// </summary>
    internal class Excercise01
    {
        // Our drawing canvas
        Bitmap canvas;
        int width;
        int height;
        // Graphics context - enables us to draw more efficiently
        Graphics g;

        // for screensaver animation
        int x = 50;
        int y = 50;
        int stepX = 1;
        int stepY = 1;

        public Excercise01(Bitmap canvas)
        {
            this.canvas = canvas;
            width = canvas.Width;
            height = canvas.Height;

            g = Graphics.FromImage(canvas);
            ClearImage();
        }

        /// <summary>
        /// Clear image = redraw all with grey
        /// </summary>
        void ClearImage()
        {
            g.Clear(Color.FromArgb(42, 42, 42));
        }

        /// <summary>
        /// Drawing sandbox
        /// Here be dragons
        /// </summary>
        internal void DrawingSandbox()
        {
            ClearImage();

            // draw square
            Pen p = new Pen(Color.White, 2);
            g.DrawRectangle(p, new Rectangle(50, 50, 10, 10));

            // draw line
            Pen p2 = new Pen(Color.Turquoise, 2);
            g.DrawLine(p2, new Point(0, 0), new Point(50, 50));

            // fill polygon
            Brush b = new SolidBrush(Color.Turquoise);
            PointF[] points = new PointF[3];
            points[0] = new PointF(width / 2 - 20, height / 2 - 10);
            points[1] = new PointF(width / 2 + 20, height / 2 - 10);
            points[2] = new PointF(width / 2, height / 2 + 10);
            g.FillPolygon(b, points);

        }

        /// <summary>
        /// Next step of square screensaver animation
        /// </summary>
        internal void NextStepSquare()
        {
            ClearImage();

            // outside of the window -> switch step sign
            if (x < 0) stepX = 1;
            if (y < 0) stepY = 1;
            if (x > width) stepX = -1;
            if (y > height) stepY = -1;

            // add step to position
            x += stepX;
            y += stepY;

            // draw rectangle
            Pen p = new Pen(Color.White, 2);
            g.DrawRectangle(p, new Rectangle(x, y, 10, 10));
        }

        internal void DrawHearts()
        {
            ClearImage();

            DrawHeart(150, 350, 10, 10);
            DrawHeart(200, 350, 10, 10);
            DrawHeart(175, 400, 10, 10);
            DrawHeart(450, 50, 50, 100);
        }

        /// <summary>
        /// Draw pink heart
        /// Height has to be larger than width
        /// </summary>
        /// <param name="xH"> X coordinate of left top corner </param>
        /// <param name="yH"> Y coordinate of left top corner </param>
        /// <param name="w"> Width of heart </param>
        /// <param name="h"> Height of heart </param>
        internal void DrawHeart(int xH, int yH, int w, int h)
        {
            if (h < w) h += w;

            int diameter = w / 2;
            int radius = diameter / 2;
            int triangleLen = h - radius;
            
            Brush b = new SolidBrush(Color.PaleVioletRed);
            Brush bl = new SolidBrush(Color.FromArgb(42,42,42));

            // draw top of the heart (two circles)
            g.FillEllipse(b, new Rectangle(xH, yH, diameter, diameter));
            g.FillEllipse(b, new Rectangle(xH + diameter, yH, diameter, diameter));
            
            PointF[] pts = new PointF[3];
            pts[0] = new PointF(xH, yH + radius);
            pts[1] = new PointF(xH + 2*diameter, yH + radius);
            pts[2] = new PointF(xH + diameter, yH + triangleLen);

            // erase bottom of the circles
            g.FillRectangle(bl, new Rectangle(xH, yH + radius, 2*diameter, diameter));
            // draw bottom of the heart
            g.FillPolygon(b, pts);
        }
    }
}
